==========
 pyRFXtrx  |Build Status| |Coverage Status|
==========

A Python library to communicate with the RFXtrx family of devices
from http://www.rfxcom.com/. Works with http://www.home-assistant.io


Using
=====

Instally via pip

::
   $ pip install -U pyRFXtrx

After that, see the examples in the examples directory


Licensing
=========

pyRFXtrx is free software: you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License as published
by the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

pyRFXtrx is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with pyRFXtrx.  See the file COPYING.txt in the distribution.
If not, see <http://www.gnu.org/licenses/>.


.. |Build Status| image:: https://travis-ci.org/Danielhiversen/pyRFXtrx.svg?branch=master
   :target: https://travis-ci.org/Danielhiversen/pyRFXtrx
.. |Coverage Status| image:: https://img.shields.io/coveralls/Danielhiversen/pyRFXtrx.svg
   :target: https://coveralls.io/r/Danielhiversen/pyRFXtrx?branch=master


